@@ -8,6 +8,7 @@ entry point
 import os
 import sys
 import time
+import fnmatch
 from concurrent import futures
 
 # local imports
@@ -20,7 +21,7 @@ from dotdrop.comparator import Comparator
 from dotdrop.importer import Importer
 from dotdrop.utils import get_tmpdir, removepath, \
     uniq_list, patch_ignores, dependencies_met, \
-    adapt_workers, check_version
+    adapt_workers, check_version, pivot_path
 from dotdrop.linktypes import LinkTypes
 from dotdrop.exceptions import YamlException, \
     UndefinedException, UnmetDependency
@@ -317,6 +318,14 @@ def cmd_install(opts):
 
     installed = []
 
+    # clear the workdir
+    if opts.install_clear_workdir and not opts.dry:
+        LOG.dbg('clearing the workdir under {}'.format(opts.workdir))
+        for root, _, files in os.walk(opts.workdir):
+            for file in files:
+                fpath = os.path.join(root, file)
+                removepath(fpath, logger=LOG)
+
     # execute profile pre-action
     LOG.dbg('run {} profile pre actions'.format(len(pro_pre_actions)))
     templ = _get_templater(opts)
@@ -371,6 +380,44 @@ def cmd_install(opts):
     return True
 
 
+def _workdir_enum(opts):
+    workdir_files = []
+    for root, _, files in os.walk(opts.workdir):
+        for file in files:
+            fpath = os.path.join(root, file)
+            workdir_files.append(fpath)
+
+    for dotfile in opts.dotfiles:
+        src = os.path.join(opts.dotpath, dotfile.src)
+        if dotfile.link == LinkTypes.NOLINK:
+            # ignore not link files
+            continue
+        if not Templategen.is_template(src):
+            # ignore not template
+            continue
+        newpath = pivot_path(dotfile.dst, opts.workdir,
+                             striphome=True, logger=None)
+        if os.path.isdir(newpath):
+            # recursive
+            pattern = '{}/*'.format(newpath)
+            files = workdir_files.copy()
+            for file in files:
+                if fnmatch.fnmatch(file, pattern):
+                    workdir_files.remove(file)
+            # only checks children
+            children = [f.path for f in os.scandir(newpath)]
+            for child in children:
+                if child in workdir_files:
+                    workdir_files.remove(child)
+        else:
+            if newpath in workdir_files:
+                workdir_files.remove(newpath)
+    for wfile in workdir_files:
+        line = '=> \"{}\" does not exist in dotdrop'
+        LOG.log(line.format(wfile))
+    return len(workdir_files)
+
+
 def cmd_compare(opts, tmp):
     """compare dotfiles and return True if all identical"""
     dotfiles = opts.dotfiles
@@ -416,6 +463,9 @@ def cmd_compare(opts, tmp):
                 same = False
             cnt += 1
 
+    if opts.compare_workdir and _workdir_enum(opts) > 0:
+        same = False
+
     LOG.log('\n{} dotfile(s) compared.'.format(cnt))
     return same
 
